@@ -18,11 +18,24 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 import os
-from PyQt4 import QtGui, QtCore
+
+from PyQt5 import (
+    QtCore,
+    QtWidgets,
+)
+
 from picard import config
-from picard.util import webbrowser2, find_executable
 from picard.const import FPCALC_NAMES
-from picard.ui.options import OptionsPage, OptionsCheckError, register_options_page
+from picard.util import (
+    find_executable,
+    webbrowser2,
+)
+
+from picard.ui.options import (
+    OptionsCheckError,
+    OptionsPage,
+    register_options_page,
+)
 from picard.ui.ui_options_fingerprinting import Ui_FingerprintingOptionsPage
 
 
@@ -42,7 +55,7 @@ class FingerprintingOptionsPage(OptionsPage):
     ]
 
     def __init__(self, parent=None):
-        super(FingerprintingOptionsPage, self).__init__(parent)
+        super().__init__(parent)
         self._fpcalc_valid = True
         self.ui = Ui_FingerprintingOptionsPage()
         self.ui.setupUi(self)
@@ -68,8 +81,8 @@ class FingerprintingOptionsPage(OptionsPage):
             config.setting["fingerprinting_system"] = "acoustid"
         else:
             config.setting["fingerprinting_system"] = ""
-        config.setting["acoustid_fpcalc"] = unicode(self.ui.acoustid_fpcalc.text())
-        config.setting["acoustid_apikey"] = unicode(self.ui.acoustid_apikey.text())
+        config.setting["acoustid_fpcalc"] = self.ui.acoustid_fpcalc.text()
+        config.setting["acoustid_apikey"] = self.ui.acoustid_apikey.text()
         config.setting["ignore_existing_acoustid_fingerprints"] = self.ui.ignore_existing_acoustid_fingerprints.isChecked()
 
     def update_groupboxes(self):
@@ -84,9 +97,9 @@ class FingerprintingOptionsPage(OptionsPage):
         self._acoustid_fpcalc_check()
 
     def acoustid_fpcalc_browse(self):
-        path = QtGui.QFileDialog.getOpenFileName(self, "", self.ui.acoustid_fpcalc.text())
+        path, _filter = QtWidgets.QFileDialog.getOpenFileName(self, "", self.ui.acoustid_fpcalc.text())
         if path:
-            path = os.path.normpath(unicode(path))
+            path = os.path.normpath(path)
             self.ui.acoustid_fpcalc.setText(path)
 
     def acoustid_fpcalc_download(self):
@@ -99,7 +112,7 @@ class FingerprintingOptionsPage(OptionsPage):
         if not self.ui.use_acoustid.isChecked():
             self._acoustid_fpcalc_set_success("")
             return
-        fpcalc = unicode(self.ui.acoustid_fpcalc.text())
+        fpcalc = self.ui.acoustid_fpcalc.text()
         if not fpcalc:
             self._acoustid_fpcalc_set_success("")
             return
@@ -113,7 +126,7 @@ class FingerprintingOptionsPage(OptionsPage):
     def _on_acoustid_fpcalc_check_finished(self, exit_code, exit_status):
         process = self.sender()
         if exit_code == 0 and exit_status == 0:
-            output = str(process.readAllStandardOutput())
+            output = bytes(process.readAllStandardOutput()).decode()
             if output.startswith("fpcalc version"):
                 self._acoustid_fpcalc_set_success(output.strip())
             else:
@@ -141,4 +154,5 @@ class FingerprintingOptionsPage(OptionsPage):
     def display_error(self, error):
         pass
 
+
 register_options_page(FingerprintingOptionsPage)
